checkNegValueDS: Checks if a numeric variable has negative values

Description Usage Arguments Details Value Author(s)

Description

this function is only called by the client function ds.glm.

Usage

1

Arguments

weights

a numeric vector

Details

if a user sets the parameter 'weights' on the client site function ds.glm this server side function is called to verify that the 'weights' vector does not have negative values because no negative are allowed in weights.

Value

a boolean; TRUE if the vector has one or more negative values and FALSE otherwise

Author(s)

Gaye, A.


datashield/dsModelling documentation built on May 14, 2019, 7:51 p.m.